"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

const util_1 = require("util");

const Ajv = require("ajv");

exports.ajv = new Ajv({
  allErrors: true,
  coerceTypes: false,
  format: 'fast',
  nullable: true,
  unicode: true,
  uniqueItems: true,
  useDefaults: true
});
exports.ajv.addMetaSchema(require('ajv/lib/refs/json-schema-draft-06.json'));
exports.MySqlConfigSchema = {
  $schema: 'http://json-schema.org/draft-07/schema#',
  defaultProperties: [],
  definitions: {
    TestConfig: {
      defaultProperties: [],
      properties: {
        connectTimeoutSeconds: {
          default: 20,
          description: 'The timeout in seconds when waiting for the test docker image to start',
          minimum: 0,
          type: 'number'
        },
        containerName: {
          default: 'mysql-test',
          description: 'The default name to give the docker\ncontainers run by @database/mysql-test',
          type: 'string'
        },
        debug: {
          default: false,
          description: 'Whether to output logs to stdout/stderr from docker\nscripts.',
          type: 'boolean'
        },
        image: {
          default: 'mysql:5.7.24',
          description: "The docker image to use when testing\nusing @databases/mysql-test. When I\ntried using the ream image it didn't\nwork very well.\n\nSee https://github.com/mysqljs/mysql/pull/1962\nfor issues supporting mysql 8",
          type: 'string'
        },
        migrationsScript: {
          anyOf: [{
            items: {
              type: 'string'
            },
            type: 'array'
          }, {
            type: 'string'
          }],
          description: 'Optional script to run after the database\nhas been started but before running tests'
        },
        mySqlDb: {
          default: 'test-db',
          description: 'The db to create in the test docker container',
          type: 'string'
        },
        mySqlPassword: {
          default: 'password',
          description: 'The password to configure in the test docker container',
          type: 'string'
        },
        mySqlUser: {
          default: 'test-user',
          description: 'The user name to configure in the test docker container',
          type: 'string'
        },
        port: {
          description: 'The port to run mysql on when running docker\nfor tests. Defaults to 3306 or the first available\nport after that.',
          maximum: 65535,
          minimum: 0,
          type: 'number'
        }
      },
      required: ['connectTimeoutSeconds', 'containerName', 'debug', 'image', 'mySqlDb', 'mySqlPassword', 'mySqlUser'],
      type: 'object'
    }
  },
  properties: {
    connectionStringEnvironmentVariable: {
      default: 'DATABASE_URL',
      description: 'The environment variable containing the\nconnection string to the mysql database',
      type: 'string'
    },
    test: {
      $ref: '#/definitions/TestConfig',
      default: {},
      description: 'Config for mysql-test'
    }
  },
  required: ['connectionStringEnvironmentVariable', 'test'],
  type: 'object'
};
const rawValidateMySqlConfig = exports.ajv.compile(exports.MySqlConfigSchema);

function validate(value) {
  if (rawValidateMySqlConfig(value)) {
    return value;
  } else {
    throw new Error(exports.ajv.errorsText(rawValidateMySqlConfig.errors, {
      dataVar: 'MySqlConfig'
    }) + '\n\n' + util_1.inspect(value));
  }
}

exports.default = validate;